function [P_max,P_min]=gjsn_bunn_topp(x_verdier,y_verdier,N)
% ------------------------------------------------------------------------------
%     Denne funksjonen beregner gjennomsnittet av bolgetoppene og bunnene.
%     Input arguments: x_verdier
%                      y_verdier
%                      N:splitter tidsaksen inn i tidsintervallet N
%     
%     Output arguments:
%                     P_max: maks gjennomsnittstrykk
%                     P_min: min. gjenomsnittstrykk
%                     
%     Call command: [P_max,P_min]=gjsn_bunn_topp(x_verdier,y_verdier,N)
%     
%     Comment: input x_verdier has to be linspaced...
%
% Written by Ingvald Bårdsen
% Date: 01.08.2003
% Student at NTNU,Trondheim
% Dept.of Chemical Engineering
% email: ingvald@stud.ntnu.no
% -----------------------------------------------------------------------------
X=find(x_verdier>=N); %finner index hvor x-verdiene skal splittes opp 
if size(X)==[0 0];
    error('Du har nok spesifisert for stort tids-interval.Prov med noe lavere N som input i gjsn_bunn_topp...')
else
X=X(1);
end

i=1;
indekser=1;
while X<length(x_verdier) 
    i=i+1;
    indekser(i)=X;
    X=X+X;
end
indekser(i+1)=length(x_verdier);

for i=1:length(indekser)-1
    P=y_verdier(indekser(i):indekser(i+1));
    P_max(i)=max(P);
    P_min(i)=min(P);
end
P_max=mean(P_max);
P_min=mean(P_min);

